Release History
===============

dev
---

**Bugfixes**

-   \[Short description of non-trivial change.\]

0.1.1
-----
- Security update for cryptography dependency


0.1.0
-----

Good initial release, include basic functionalities

- Certificate Authority
- Intermediate Certificate Authority
- Issue certificates
- Revoke certificates
- Sign CSR
- Certificate Revoke List


0.0.3
-----

- Bug fixes


0.0.2
-----

- Bug fixes

0.0.1
-----

- Basic release
  . CA
  . issue certificates

0.0.1alpha9
-----------

- This version works with some limitation (OIDs)

0.0.1 (2019-11-20)
------------------
Good start definition from requests project [https://requests.readthedocs.io] HISTORY.md :)

-   Frustration
-   Conception
